@@ -12,7 +12,6 @@ context("SDMXHelpers")
 
 #-> dataflow
 test_that("Main helpers arguments",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   
   #existing provider
@@ -33,18 +32,50 @@ test_that("Main helpers arguments",{
   
   #wrong request
   expect_error(readSDMX(providerId = "KNOEMA", resource = "data", flowRef = "SADG2015-WRONG"),
-               "HTTP request failed with status: 400 Dataset not found.")
+               "HTTP request failed with status: 400 ")
   
 })
 
 #international data providers
 
+#BIS
+#---
+
+#-> dataflow
+test_that("BIS - dataflow",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "BIS", resource = "dataflow")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataFlows")
+    expect_is(as.data.frame(sdmx), "data.frame")
+  }
+})
+
+#-> datastructure
+test_that("BIS - datastructure",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "BIS", resource = "datastructure", resourceId = "BIS_XR")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataStructureDefinition")
+  }
+})
+
+#-> data
+test_that("BIS - data",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "BIS", resource = "data",
+                   flowRef = "WS_XRU", key.mode = "SDMX",
+                   start = 2020, end = 2020)
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXStructureSpecificData")
+  }
+})
+
 #ECB
 #---
 
 #-> dataflow
 test_that("ECB - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ECB", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -54,9 +85,8 @@ test_that("ECB - dataflow",{
 
 #-> datastructure
 test_that("ECB - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ECB", resource = "datastructure", resourceId = "ECB_DD1")
+  sdmx <- readSDMX(providerId = "ECB", resource = "datastructure", resourceId = "ECB_EST1")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXDataStructureDefinition")
   }
@@ -64,11 +94,10 @@ test_that("ECB - datastructure",{
 
 #-> data
 test_that("ECB - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ECB", resource = "data",
-                   flowRef = "DD", key = "M.SE.BSI_STF.RO.4F_N", key.mode = "SDMX",
-                   start = 2010, end = 2010)
+                   flowRef = "DD", key = "all", key.mode = "SDMX",
+                   start = 2020, end = 2020)
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXGenericData")
   }
@@ -79,7 +108,6 @@ test_that("ECB - data",{
 
 #-> dataflow
 test_that("ESTAT - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ESTAT", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -89,9 +117,8 @@ test_that("ESTAT - dataflow",{
 
 #-> datastructure
 test_that("ESTAT - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ESTAT", resource = "datastructure", resourceId = "DSD_nama_gdp_c")
+  sdmx <- readSDMX(providerId = "ESTAT", resource = "datastructure", resourceId = "DSD_tec00118")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXDataStructureDefinition")
   }
@@ -99,11 +126,10 @@ test_that("ESTAT - datastructure",{
 
 #-> data
 test_that("ESTAT - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ESTAT", resource = "data",
-                   flowRef = "cdh_e_fos", key = list(NULL, NULL, "PC", "FOS1", "BE"),
-                   start = 2005, end = 2010)
+                   flowRef = "tec00118", key = "all",
+                   start = 2020, end = 2020)
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXGenericData")
   }
@@ -114,7 +140,6 @@ test_that("ESTAT - data",{
 
 #-> dataflow
 test_that("IMF - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "IMF", resource = "dataflow", agencyId = "IMF")
   if(!is.null(sdmx)){
@@ -124,7 +149,6 @@ test_that("IMF - dataflow",{
 
 #-> datastructure
 test_that("IMF - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "IMF", resource = "datastructure", resourceId = "BOP")
   if(!is.null(sdmx)){
@@ -134,13 +158,12 @@ test_that("IMF - datastructure",{
 
 #-> data
 test_that("IMF - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "IMF", resource = "data",
-                   flowRef = "BOP_GBPM6", start = 2010, end = 2015) 
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXStructureSpecificData")
-  }
+  #TODO to test, sounds it's not public anymore
+  #sdmx <- readSDMX(providerId = "IMF", resource = "data", flowRef = "BOP_GBPM6", start = 2020, end = 2020) 
+  #if(!is.null(sdmx)){
+  #  expect_is(sdmx, "SDMXStructureSpecificData")
+  #}
 })
 
 #OECD
@@ -148,7 +171,6 @@ test_that("IMF - data",{
 
 #-> dataflow
 test_that("OECD - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "OECD", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -158,7 +180,6 @@ test_that("OECD - dataflow",{
 
 #-> datastructure
 test_that("OECD - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "OECD", resource = "datastructure", resourceId = "TABLE1")
   if(!is.null(sdmx)){
@@ -168,7 +189,6 @@ test_that("OECD - datastructure",{
 
 #-> data
 test_that("OECD - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "OECD", resource = "data",
                    flowRef = "MIG", key = list("TOT", NULL, NULL), start = 2011, end = 2011)
@@ -177,12 +197,76 @@ test_that("OECD - data",{
   }
 })
 
+#UNICEF
+#----
+
+#-> dataflow
+test_that("UNICEF - dataflow",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "UNICEF", resource = "dataflow")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataFlows")
+  }
+})
+
+#-> datastructure
+test_that("UNICEF - datastructure",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "UNICEF", resource = "datastructure", resourceId = "COVID")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataStructureDefinition")
+  }
+})
+
+#-> data
+test_that("UNICEF - data",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "UNICEF", resource = "data",
+                   flowRef = "COVID", key = NULL)
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXStructureSpecificData")
+  }
+})
+
+
+
+#CD2030
+#----
+
+#-> dataflow
+test_that("CD2030 - dataflow",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "CD2030", resource = "dataflow")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataFlows")
+  }
+})
+
+#-> datastructure
+test_that("CD2030 - datastructure",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "CD2030", resource = "datastructure", resourceId = "CDDEM")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataStructureDefinition")
+  }
+})
+
+#-> data
+test_that("CD2030 - data",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "CD2030", resource = "data",
+                   flowRef = "CDDEM", key = NULL)
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXStructureSpecificData")
+  }
+})
+
+
 #UNSD (UN-DATA)
 #----
 
 #-> dataflow
 test_that("UNSD - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "UNSD", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -192,7 +276,6 @@ test_that("UNSD - dataflow",{
 
 #-> datastructure
 test_that("UNSD - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "UNSD", resource = "datastructure", resourceId = "CountryData")
   if(!is.null(sdmx)){
@@ -202,7 +285,6 @@ test_that("UNSD - datastructure",{
 
 #-> data
 test_that("UNSD - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "UNSD", resource = "data",
                    flowRef = "DF_UNDATA_COUNTRYDATA", key = NULL,
@@ -212,37 +294,12 @@ test_that("UNSD - data",{
   }
 })
 
-#FAO (UN-FAO)
-#------------
-
-#-> datastructure
-test_that("FAO - datastructure",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "FAO", resource = "datastructure", resourceId = "FAOSTAT")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
-
-#-> data
-test_that("FAO - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "FAO", resource = "data",
-                   flowRef = "CROP_PRODUCTION", key = list(NULL, "156", "5312", NULL, NULL),
-                   start = "2010", end = "2014")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXGenericData")
-  }
-})
 
 #ILO_Legacy (UN-ILO)
 #------------
 
 #-> datastructure
 test_that("ILO - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ILO_Legacy", resource = "datastructure", resourceId = "YI_ALB_EAP_TEAP_SEX_AGE_NB")
   if(!is.null(sdmx)){
@@ -252,7 +309,6 @@ test_that("ILO - datastructure",{
 
 #-> data
 test_that("ILO - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ILO_Legacy", resource = "data",
                    flowRef = "DF_CPI_FRA_CPI_TCPI_COI_RT", key = "ALL", key.mode = "SDMX",
@@ -267,7 +323,6 @@ test_that("ILO - data",{
 
 #-> dataflow
 test_that("ILO - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ILO", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -277,9 +332,8 @@ test_that("ILO - dataflow",{
 
 #-> datastructure
 test_that("ILO - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "ILO", resource = "datastructure", resourceId = "ILOEST_ALL_EAP_2EAP_SEX_AGE_NB")
+  sdmx <- readSDMX(providerId = "ILO", resource = "datastructure", resourceId = "DF_CLD_TPOP_SEX_AGE_GEO_NB")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXDataStructureDefinition")
   }
@@ -287,103 +341,20 @@ test_that("ILO - datastructure",{
 
 #-> data
 test_that("ILO - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ILO", resource = "data",
-                   flowRef = "ILOEST_ALL_EAP_2EAP_SEX_AGE_NB", key = "ALL", key.mode = "SDMX",
-                   start = "2010-01-01", end = "2014-12-31")
+                   flowRef = "DF_CLD_TPOP_SEX_AGE_GEO_NB", key = "ALL", key.mode = "SDMX",
+                   start = "2020-01-01", end = "2020-12-31")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXGenericData")
   }
 })
 
-#UIS (UNESCO)
-#------------
-
-#-> dataflow
-test_that("UIS - dataflow",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "UIS", resource = "dataflow")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataFlows")
-  }
-})
-
-#-> datastructure
-test_that("UIS - datastructure",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "UIS", resource = "datastructure", resourceId = "EDULIT_DS")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
-
-#-> data
-test_that("UIS - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "UIS", resource = "data",
-                   flowRef = "EDULIT_DS", key = list("OFST_1_CP", NULL),
-                   start = "2000", end = "2015")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXMessageGroup")
-  }
-})
-
-#UIS2 (UNESCO - new API https://apiportal.uis.unesco.org)
-#------------
-
-#-> dataflow
-test_that("UIS2 - dataflow",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  
-  apiKey <- Sys.getenv("UIS_API_KEY")
-  if(apiKey != ""){
-    sdmx <- readSDMX(providerId = "UIS2", providerKey = apiKey, resource = "dataflow")
-    if(!is.null(sdmx)){
-      expect_is(sdmx, "SDMXDataFlows")
-    }
-  }
-})
-
-#-> datastructure
-test_that("UIS2 - datastructure",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  
-  apiKey <- Sys.getenv("UIS_API_KEY")
-  if(apiKey != ""){
-    sdmx <- readSDMX(providerId = "UIS2", providerKey = apiKey, resource = "datastructure", resourceId = "CE")
-    if(!is.null(sdmx)){
-      expect_is(sdmx, "SDMXDataStructureDefinition")
-    }
-  }
-})
-
-#-> data
-test_that("UIS2 - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  
-  apiKey <- Sys.getenv("UIS_API_KEY")
-  if(apiKey != ""){
-    sdmx <- readSDMX(providerId = "UIS2", providerKey = apiKey, resource = "data",
-                     flowRef = "CE", start = "2000", end = "2015")
-    if(!is.null(sdmx)){
-      expect_is(sdmx, "SDMXStructureSpecificData")
-    }
-  }
-})
-
 #WBG_WITS
 #--------
 
 #-> dataflow
 test_that("WBG_WITS - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "WBG_WITS", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -393,7 +364,6 @@ test_that("WBG_WITS - dataflow",{
 
 #-> datastructure
 test_that("WBG_WITS - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "WBG_WITS", resource = "datastructure", resourceId = "TARIFF_TRAINS")
   if(!is.null(sdmx)){
@@ -403,7 +373,6 @@ test_that("WBG_WITS - datastructure",{
 
 #-> data
 test_that("WBG_WITS - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "WBG_WITS", resource = "data",
                    key = ".840.000.020110.reported", key.mode = "SDMX",
@@ -413,6 +382,70 @@ test_that("WBG_WITS - data",{
   }
 })
 
+#WB (World Bank)
+#--------
+
+#-> dataflow
+test_that("WB - dataflow",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "WB", resource = "dataflow")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataFlows")
+  }
+})
+
+#-> datastructure
+test_that("WB - datastructure",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "WB", resource = "datastructure", resourceId = "WDI")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataStructureDefinition")
+  }
+})
+
+#-> data
+test_that("WB - data",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "WB", resource = "data",
+                   key = "A.SP_POP_TOTL.AFG", key.mode = "SDMX",
+                   flowRef = "WDI", start = "2011", end = "2011")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXGenericData")
+  }
+})
+
+#PDH (Pacific Data Hub)
+#--------
+
+#-> dataflow
+test_that("PDH - dataflow",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "PDH", resource = "dataflow")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataFlows")
+  }
+})
+
+#-> datastructure
+test_that("PDH - datastructure",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "PDH", resource = "datastructure", resourceId = "DSD_CPI")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataStructureDefinition")
+  }
+})
+
+#-> data
+test_that("PDH - data",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "PDH", resource = "data",
+                   key = "A.FJ.INF.", key.mode = "SDMX",
+                   flowRef = "DF_CPI", start = "2015", end = "2019")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXGenericData")
+  }
+})
+
 #national data providers
 
 #ABS (Australia)
@@ -420,7 +453,6 @@ test_that("WBG_WITS - data",{
 
 #-> datastructure
 test_that("ABS - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ABS", resource = "datastructure", resourceId = "ALC")
   if(!is.null(sdmx)){
@@ -430,13 +462,12 @@ test_that("ABS - datastructure",{
 
 #-> data
 test_that("ABS - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ABS", resource = "data",
                    flowRef = "ALC", key = "1.1+2.1+2+3+5+4.6+10+11+12+15+14.A", key.mode = "SDMX",
                    start = "2000", end = "2015")
   if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXMessageGroup")
+    expect_is(sdmx, "SDMXGenericData")
   }
 })
 
@@ -445,7 +476,6 @@ test_that("ABS - data",{
 
 #-> datastructure
 test_that("NBB - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NBB", resource = "datastructure", resourceId = "QNA")
   if(!is.null(sdmx)){
@@ -455,7 +485,6 @@ test_that("NBB - datastructure",{
 
 #-> data
 test_that("NBB - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NBB", resource = "data",
                    flowRef = "QNA", key = "all", key.mode = "SDMX",
@@ -470,7 +499,6 @@ test_that("NBB - data",{
 
 #-> dataflow
 test_that("INSEE - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "INSEE", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -480,7 +508,6 @@ test_that("INSEE - dataflow",{
 
 #-> datastructure
 test_that("INSEE - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "INSEE", resource = "datastructure", resourceId = "CONSO-MENAGES-2010")
   if(!is.null(sdmx)){
@@ -490,7 +517,6 @@ test_that("INSEE - datastructure",{
 
 #-> data
 test_that("INSEE - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "INSEE", resource = "data",
                    flowRef = "CONSO-MENAGES-2010", key = "all", key.mode = "SDMX",
@@ -505,7 +531,6 @@ test_that("INSEE - data",{
 
 #-> dataflow
 test_that("INEGI - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "INEGI", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -515,9 +540,8 @@ test_that("INEGI - dataflow",{
 
 #-> datastructure
 test_that("INEGI - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "INEGI", resource = "datastructure", resourceId = "NAWWE")
+  sdmx <- readSDMX(providerId = "INEGI", resource = "datastructure", resourceId = "SDG")
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXDataStructureDefinition")
   }
@@ -525,10 +549,9 @@ test_that("INEGI - datastructure",{
 
 #-> data
 test_that("INEGI - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "INEGI", resource = "data",
-                   flowRef = "DF_PIB_PB2008", start = 2010, end = 2015)
+                   flowRef = "SDG", start = 2020, end = 2020)
   if(!is.null(sdmx)){
     expect_is(sdmx, "SDMXGenericData")
   }
@@ -539,7 +562,6 @@ test_that("INEGI - data",{
 
 #-> dataflow
 test_that("ISTAT - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ISTAT", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -550,7 +572,6 @@ test_that("ISTAT - dataflow",{
 #-> datastructure
 #TODO investigate issue with xmlNamespaceDefinitions (XML)
 test_that("ISTAT - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ISTAT", resource = "datastructure", resourceId = "DCCV_CONSACQUA")
   if(!is.null(sdmx)){
@@ -560,7 +581,6 @@ test_that("ISTAT - datastructure",{
 
 #-> data
 test_that("ISTAT - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "ISTAT", resource = "data",
                    flowRef = "12_60", start = 2015, end = 2015)
@@ -574,7 +594,6 @@ test_that("ISTAT - data",{
 
 #-> dataflow
 test_that("NOMIS - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NOMIS", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -583,8 +602,8 @@ test_that("NOMIS - dataflow",{
 })
 
 #-> datastructure
+#TODO check invalid XML
 test_that("NOMIS - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NOMIS", resource = "datastructure", resourceId = "NM_1_1")
   if(!is.null(sdmx)){
@@ -594,11 +613,10 @@ test_that("NOMIS - datastructure",{
 
 #-> data
 test_that("NOMIS - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NOMIS", resource = "data", flowRef="NM_1_1")
   if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXGenericData")
+    expect_is(sdmx, "SDMXCompactData")
   }
 })
 
@@ -606,33 +624,30 @@ test_that("NOMIS - data",{
 #----------
 
 #-> datastructure
-test_that("UKDS - datastructure",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "UKDS", resource = "datastructure", resourceId = "QNA")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
+#test_that("UKDS - datastructure",{
+#  testthat::skip_on_cran()
+#  sdmx <- readSDMX(providerId = "UKDS", resource = "datastructure", resourceId = "QNA")
+#  if(!is.null(sdmx)){
+#    expect_is(sdmx, "SDMXDataStructureDefinition")
+#  }
+#})
 
 #-> data
-test_that("UKDS - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "UKDS", resource = "data", flowRef="QNA",
-                   key = "AUS+AUT.GDP+B1_GE.CUR+VOBARSA.Q", key.mode = "SDMX",
-                   start = 2000, end = 2000, dsd =TRUE)
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXMessageGroup")
-  }
-})
+#test_that("UKDS - data",{
+#  testthat::skip_on_cran()
+#  sdmx <- readSDMX(providerId = "UKDS", resource = "data", flowRef="QNA",
+#                   key = "AUS+AUT.GDP+B1_GE.CUR+VOBARSA.Q", key.mode = "SDMX",
+#                   start = 2000, end = 2000, dsd =TRUE)
+#  if(!is.null(sdmx)){
+#    expect_is(sdmx, "SDMXMessageGroup")
+#  }
+#})
 
 #LSD (LITHUANIA)
 #-------------
 
 #-> dataflow
 test_that("LSD - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "LSD", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -642,7 +657,6 @@ test_that("LSD - dataflow",{
 
 #-> datastructure
 test_that("LSD - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "LSD", resource = "datastructure", resourceId = "M8020420")
   if(!is.null(sdmx)){
@@ -652,7 +666,6 @@ test_that("LSD - datastructure",{
 
 #-> data
 test_that("LSD - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "LSD", resource = "data",
                    flowRef = "S3R629_M3010217", start = 2010, end = 2015)
@@ -666,7 +679,6 @@ test_that("LSD - data",{
 
 #-> dataflow
 test_that("NCSI - dataflow",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NCSI", resource = "dataflow")
   if(!is.null(sdmx)){
@@ -676,7 +688,6 @@ test_that("NCSI - dataflow",{
 
 #-> datastructure
 test_that("NCSI - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "NCSI", resource = "datastructure", resourceId = "OMFSRS2016")
   if(!is.null(sdmx)){
@@ -685,21 +696,20 @@ test_that("NCSI - datastructure",{
 })
 
 #-> data
-test_that("NCSI - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "NCSI", resource = "data", flowRef = "OMFSRS2016", start = 2010, end = 2015)
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXStructureSpecificData")
-  }
-})
+#TODO needs authorization
+#test_that("NCSI - data",{
+#  testthat::skip_on_cran()
+#  sdmx <- readSDMX(providerId = "NCSI", resource = "data", flowRef = "OMFSRS2016", start = 2010, end = 2015)
+#  if(!is.null(sdmx)){
+#    expect_is(sdmx, "SDMXStructureSpecificData")
+#  }
+#})
 
 #STAT_E (Estonia)
 #-------------
 
 #-> datastructure
 test_that("STAT_EE - datastructure",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "STAT_EE", resource = "datastructure", resourceId = "KK11")
   if(!is.null(sdmx)){
@@ -709,7 +719,6 @@ test_that("STAT_EE - datastructure",{
 
 #-> data
 test_that("STAT_EE - data",{
-  testthat::skip_on_travis()
   testthat::skip_on_cran()
   sdmx <- readSDMX(providerId = "STAT_EE", resource = "data",
                    flowRef = "KK11", key = "all", key.mode = "SDMX",
@@ -720,73 +729,62 @@ test_that("STAT_EE - data",{
 })
 
 
+#BBK (Bundesbank)
+#-------------
+#-> dataflow
+test_that("BBK - dataflow",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "BBK", resource = "dataflow")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataFlows")
+  }
+})
+
+test_that("BBK - datastructure",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "BBK", resource = "datastructure", resourceId = "BBK_SEDI")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXDataStructureDefinition")
+  }
+})
+
+test_that("BBK - data",{
+  testthat::skip_on_cran()
+  sdmx <- readSDMX(providerId = "BBK", resource = "data", flowRef = "BBSIS", key = "D.I.ZST.B0.EUR.S1311.B.A604._Z.R.A.A._Z._Z.A")
+  if(!is.null(sdmx)){
+    expect_is(sdmx, "SDMXGenericData")
+  }
+})
+
+
 #other data providers
 
 #KNOEMA
 #------
 
 #-> dataflow
-test_that("KNOEMA - dataflow",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "KNOEMA", resource = "dataflow")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataFlows")
-  }
-})
+#test_that("KNOEMA - dataflow",{
+#  testthat::skip_on_cran()
+#  sdmx <- readSDMX(providerId = "KNOEMA", resource = "dataflow")
+#  if(!is.null(sdmx)){
+#    expect_is(sdmx, "SDMXDataFlows")
+#  }
+#})
 
 #-> datastructure
-test_that("KNOEMA - datastructure",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "KNOEMA", resource = "datastructure", resourceId = "SADG2015")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
+#test_that("KNOEMA - datastructure",{
+#  testthat::skip_on_cran()
+#  sdmx <- readSDMX(providerId = "KNOEMA", resource = "datastructure", resourceId = "SADG2015")
+#  if(!is.null(sdmx)){
+#    expect_is(sdmx, "SDMXDataStructureDefinition")
+#  }
+#})
 
 #-> data
-test_that("KNOEMA - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "KNOEMA", resource = "data", flowRef = "SADG2015")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXStructureSpecificData")
-  }
-})
-
-#WIDUKIND
-#--------
-
-#-> dataflow
-test_that("WIDUKIND - dataflow",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "WIDUKIND", resource = "dataflow")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataFlows")
-  }
-})
-
-#-> datastructure
-test_that("WIDUKIND - datastructure",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "WIDUKIND", resource = "datastructure",
-                   agencyId = "INSEE", resourceId = "POP-EVO")
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXDataStructureDefinition")
-  }
-})
-
-#-> data
-test_that("WIDUKIND - data",{
-  testthat::skip_on_travis()
-  testthat::skip_on_cran()
-  sdmx <- readSDMX(providerId = "WIDUKIND", resource = "data", agencyId = "INSEE",
-                   flowRef = "IPCH-2015-FR-COICOP", key = "a.07120.indice", key.mode="SDMX",
-                   start = 2010, end = 2015)
-  if(!is.null(sdmx)){
-    expect_is(sdmx, "SDMXStructureSpecificData")
-  }
-})
+#test_that("KNOEMA - data",{
+#  testthat::skip_on_cran()
+#  sdmx <- readSDMX(providerId = "KNOEMA", resource = "data", flowRef = "SADG2015")
+#  if(!is.null(sdmx)){
+#    expect_is(sdmx, "SDMXStructureSpecificData")
+#  }
+#})
